@@ -27,7 +27,7 @@
 #' }
 
 mat_2scipy_sparse = function(x, format = 'sparse_row_matrix') {
-  
+
   if (!inherits(x, "matrix")) stop("the 'x' parameter should be of type 'matrix'", call. = F)
 
   if (format == 'sparse_column_matrix') {
@@ -53,69 +53,69 @@ mat_2scipy_sparse = function(x, format = 'sparse_row_matrix') {
 #' @details
 #' This function allows the user to convert either an R \emph{dgCMatrix} or a \emph{dgRMatrix} to a scipy sparse matrix (\emph{scipy.sparse.csc_matrix} or \emph{scipy.sparse.csr_matrix}). This is useful because the \emph{nmslibR} package accepts besides an R dense matrix also python sparse matrices as input.
 #'
-#' The \emph{dgCMatrix} class is a class of sparse numeric matrices in the compressed, sparse, \emph{column-oriented format}. The \emph{dgRMatrix} class is a class of sparse numeric matrices in the compressed, sparse, \emph{column-oriented format}. 
+#' The \emph{dgCMatrix} class is a class of sparse numeric matrices in the compressed, sparse, \emph{column-oriented format}. The \emph{dgRMatrix} class is a class of sparse numeric matrices in the compressed, sparse, \emph{column-oriented format}.
 #'
 #' @export
 #' @import reticulate
 #' @importFrom Matrix Matrix
 #' @references https://stat.ethz.ch/R-manual/R-devel/library/Matrix/html/dgCMatrix-class.html, https://stat.ethz.ch/R-manual/R-devel/library/Matrix/html/dgRMatrix-class.html, https://docs.scipy.org/doc/scipy/reference/generated/scipy.sparse.csc_matrix.html#scipy.sparse.csc_matrix
 #' @examples
-#' 
+#'
 #' if (reticulate::py_available() && reticulate::py_module_available("scipy")) {
-#'   
+#'
 #'   if (Sys.info()["sysname"] != 'Darwin') {
-#' 
+#'
 #'     library(nmslibR)
-#'   
-#'   
+#'
+#'
 #'     # 'dgCMatrix' sparse matrix
 #'     #--------------------------
-#'   
+#'
 #'     data = c(1, 0, 2, 0, 0, 3, 4, 5, 6)
-#'   
+#'
 #'     dgcM = Matrix::Matrix(data = data, nrow = 3,
-#'   
+#'
 #'                           ncol = 3, byrow = TRUE,
-#'   
+#'
 #'                           sparse = TRUE)
-#'   
+#'
 #'     print(dim(dgcM))
-#'   
+#'
 #'     res = TO_scipy_sparse(dgcM)
-#'   
+#'
 #'     print(res$shape)
-#'     
-#'     
+#'
+#'
 #'     # 'dgRMatrix' sparse matrix
 #'     #--------------------------
-#'     
+#'
 #'     dgrM = as(dgcM, "RsparseMatrix")
-#'     
+#'
 #'     print(dim(dgrM))
-#'   
+#'
 #'     res_dgr = TO_scipy_sparse(dgrM)
-#'   
+#'
 #'     print(res_dgr$shape)
 #'   }
 #' }
 
 TO_scipy_sparse = function(R_sparse_matrix) {
-  
+
   if (inherits(R_sparse_matrix, "dgCMatrix")) {
-    
+
     py_obj = SCP$sparse$csc_matrix(reticulate::tuple(R_sparse_matrix@x, R_sparse_matrix@i, R_sparse_matrix@p), shape = reticulate::tuple(R_sparse_matrix@Dim[1], R_sparse_matrix@Dim[2]))
   }
-  
+
   else if (inherits(R_sparse_matrix, "dgRMatrix")) {
-    
+
     py_obj = SCP$sparse$csr_matrix(reticulate::tuple(R_sparse_matrix@x, R_sparse_matrix@j, R_sparse_matrix@p), shape = reticulate::tuple(R_sparse_matrix@Dim[1], R_sparse_matrix@Dim[2]))
   }
-  
+
   else {
-    
-    stop("the 'R_sparse_matrix' parameter should be either a 'dgCMatrix' or a 'dgRMatrix' sparse matrix", call. = F) 
+
+    stop("the 'R_sparse_matrix' parameter should be either a 'dgCMatrix' or a 'dgRMatrix' sparse matrix", call. = F)
   }
-  
+
   return(py_obj)
 }
 
@@ -134,7 +134,7 @@ TO_scipy_sparse = function(R_sparse_matrix) {
 #' @param space_params a list of (optional) parameters for configuring the space. See the \emph{references} manual for more details.
 #' @param method a character string specifying the index method to use
 #' @param data_type a character string. One of 'DENSE_UINT8_VECTOR', 'DENSE_VECTOR', 'OBJECT_AS_STRING' or 'SPARSE_VECTOR'
-#' @param dtype a character string. One of 'DOUBLE', 'FLOAT', 'INT'
+#' @param dtype a character string. Either 'FLOAT' or 'INT'
 #' @param print_progress a boolean (either TRUE or FALSE). Whether or not to display progress bar
 #' @param num_threads an integer. The number of threads to use
 #' @param index_filepath a character string specifying the path to a file, where an existing index is saved
@@ -152,7 +152,7 @@ TO_scipy_sparse = function(R_sparse_matrix) {
 #'
 #' If the \emph{index_filepath} parameter is not NULL then an existing index will be loaded
 #'
-#' @references \emph{https://github.com/searchivarius/nmslib/blob/master/manual/manual.pdf}
+#' @references \emph{https://github.com/nmslib/nmslib/blob/master/manual/latex/manual.pdf}
 #' @docType class
 #' @importFrom R6 R6Class
 #' @import reticulate
@@ -301,7 +301,13 @@ NMSlib <- R6::R6Class("NMSlib",
 
                            idx_dists_single_ROW = private$index$knnQuery(query_data_row, as.integer(k + 1))             # add 1 because I'll remove the first item ( see next line )
 
-                           return(lapply(idx_dists_single_ROW, function(y) y[-1]))                                      # remove first item as it represents the distance between a row with itself
+                           indices = idx_dists_single_ROW[[1]]
+                           indices = indices[-1] + 1                                                                    # remove the first item as it represents the distance between a row with itself   &   account for the indexing differences betw. Python and R
+
+                           values = idx_dists_single_ROW[[2]]
+                           values = values[-1]
+
+                           return(list(indices, values))
                          },
 
 
@@ -340,12 +346,12 @@ NMSlib <- R6::R6Class("NMSlib",
 
 
 #' import internal functions from the KernelKnn package
-#' 
+#'
 #' @importFrom utils getFromNamespace
 #' @keywords internal
 
 import_internal = function(function_name) {
-  
+
   utils::getFromNamespace(function_name, "KernelKnn")
 }
 
@@ -356,9 +362,9 @@ import_internal = function(function_name) {
 #' @keywords internal
 
 inner_kernel_function = function(y_matrix, dist_matrix, Levels, weights_function, h) {
-  
+
   #------------------------------------ import internal functions from KernelKnn
-  
+
   normalized = import_internal('normalized')
   func_tbl_dist = import_internal('func_tbl_dist')
   func_tbl = import_internal('func_tbl')
@@ -370,8 +376,8 @@ inner_kernel_function = function(y_matrix, dist_matrix, Levels, weights_function
   func_shuffle = import_internal('func_shuffle')
   class_folds = import_internal('class_folds')
   regr_folds = import_internal('regr_folds')
-  
-  #------------------------------------ 
+
+  #------------------------------------
 
   if (is.null(Levels)) {                                                          # regression
 
@@ -448,7 +454,7 @@ inner_kernel_function = function(y_matrix, dist_matrix, Levels, weights_function
 #' @param space_params a list of (optional) parameters for configuring the space. See the \emph{references} manual for more details.
 #' @param method a character string specifying the index method to use
 #' @param data_type a character string. One of 'DENSE_UINT8_VECTOR', 'DENSE_VECTOR', 'OBJECT_AS_STRING' or 'SPARSE_VECTOR'
-#' @param dtype a character string. One of 'DOUBLE', 'FLOAT', 'INT'
+#' @param dtype a character string. Either 'FLOAT' or 'INT'
 #' @param print_progress a boolean (either TRUE or FALSE). Whether or not to display progress bar
 #' @param num_threads an integer. The number of threads to use
 #' @param index_filepath a character string specifying the path to a file, where an existing index is saved
@@ -525,7 +531,7 @@ KernelKnn_nmslib = function(data, TEST_data = NULL, y, k = 5, h = 1.0, weights_f
 #' @param space_params a list of (optional) parameters for configuring the space. See the \emph{references} manual for more details.
 #' @param method a character string specifying the index method to use
 #' @param data_type a character string. One of 'DENSE_UINT8_VECTOR', 'DENSE_VECTOR', 'OBJECT_AS_STRING' or 'SPARSE_VECTOR'
-#' @param dtype a character string. One of 'DOUBLE', 'FLOAT', 'INT'
+#' @param dtype a character string. Either 'FLOAT' or 'INT'
 #' @param print_progress a boolean (either TRUE or FALSE). Whether or not to display progress bar
 #' @param num_threads an integer. The number of threads to use
 #' @param index_filepath a character string specifying the path to a file, where an existing index is saved
@@ -553,13 +559,13 @@ KernelKnnCV_nmslib = function(data, y, k = 5, folds = 5, h = 1.0, weights_functi
                               dtype = 'FLOAT', index_filepath = NULL, print_progress = FALSE, num_threads = 1, seed_num = 1) {
 
   start = Sys.time()
-  
+
   #------------------------------------ import internal functions from KernelKnn
-  
+
   class_folds = import_internal('class_folds')
   regr_folds = import_internal('regr_folds')
-  
-  #------------------------------------ 
+
+  #------------------------------------
 
   if (is.null(Levels)) {
 
